# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from . import euclidesproto_pb2 as euclidesproto__pb2


class SimilarStub(object):
  # missing associated documentation comment in .proto file
  pass

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.Shutdown = channel.unary_unary(
        '/euclidesproto.Similar/Shutdown',
        request_serializer=euclidesproto__pb2.ShutdownRequest.SerializeToString,
        response_deserializer=euclidesproto__pb2.ShutdownReply.FromString,
        )
    self.FindSimilar = channel.unary_unary(
        '/euclidesproto.Similar/FindSimilar',
        request_serializer=euclidesproto__pb2.FindSimilarRequest.SerializeToString,
        response_deserializer=euclidesproto__pb2.FindSimilarReply.FromString,
        )
    self.AddImage = channel.unary_unary(
        '/euclidesproto.Similar/AddImage',
        request_serializer=euclidesproto__pb2.AddImageRequest.SerializeToString,
        response_deserializer=euclidesproto__pb2.AddImageReply.FromString,
        )
    self.RemoveImage = channel.unary_unary(
        '/euclidesproto.Similar/RemoveImage',
        request_serializer=euclidesproto__pb2.RemoveImageRequest.SerializeToString,
        response_deserializer=euclidesproto__pb2.RemoveImageReply.FromString,
        )


class SimilarServicer(object):
  # missing associated documentation comment in .proto file
  pass

  def Shutdown(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def FindSimilar(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def AddImage(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def RemoveImage(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_SimilarServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'Shutdown': grpc.unary_unary_rpc_method_handler(
          servicer.Shutdown,
          request_deserializer=euclidesproto__pb2.ShutdownRequest.FromString,
          response_serializer=euclidesproto__pb2.ShutdownReply.SerializeToString,
      ),
      'FindSimilar': grpc.unary_unary_rpc_method_handler(
          servicer.FindSimilar,
          request_deserializer=euclidesproto__pb2.FindSimilarRequest.FromString,
          response_serializer=euclidesproto__pb2.FindSimilarReply.SerializeToString,
      ),
      'AddImage': grpc.unary_unary_rpc_method_handler(
          servicer.AddImage,
          request_deserializer=euclidesproto__pb2.AddImageRequest.FromString,
          response_serializer=euclidesproto__pb2.AddImageReply.SerializeToString,
      ),
      'RemoveImage': grpc.unary_unary_rpc_method_handler(
          servicer.RemoveImage,
          request_deserializer=euclidesproto__pb2.RemoveImageRequest.FromString,
          response_serializer=euclidesproto__pb2.RemoveImageReply.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'euclidesproto.Similar', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))
